const chai = require('chai');
const Rabbit = require('./../lib/rabbit.js');
const should = chai.should();

describe('Converting',()=>{
  describe('Zawgyi to Unicode', () => {
    it('Convert to Unicode', done => {
      Rabbit.zg2uni("မဂၤလာပါ").should.equal("မင်္ဂလာပါ");
      Rabbit.zg2uni("သီဟိုဠ္မွ ဉာဏ္ႀကီးရွင္သည္ အာယုဝဍ္ဎနေဆးၫႊန္းစာကို ဇလြန္ေဈးေဘးဗာဒံပင္ထက္ အဓိ႒ာန္လ်က္ ဂဃနဏဖတ္ခဲ့သည္။").should.equal("သီဟိုဠ်မှ ဉာဏ်ကြီးရှင်သည် အာယုဝဍ်ဎနဆေးညွှန်းစာကို ဇလွန်ဈေးဘေးဗာဒံပင်ထက် အဓိဋ္ဌာန်လျက် ဂဃနဏဖတ်ခဲ့သည်။");
      Rabbit.zg2uni("ေယဓမၼာ ေဟတုပၸဘဝါ ေတသံ ေဟတုံ တထာဂေတာ အာဟ ေတသၪၥ ေယာနိေရာေဓါ ဧဝံ ဝါဒီ မဟာသမေဏာ။").should.equal("ယေဓမ္မာ ဟေတုပ္ပဘဝါ တေသံ ဟေတုံ တထာဂတော အာဟ တေသဉ္စ ယောနိရောဓေါ ဧဝံ ဝါဒီ မဟာသမဏော။");
      Rabbit.zg2uni("Rabbit ကြန္ဗက္တာကို သိလား").should.equal("Rabbit ကွန်ဗက်တာကို သိလား");
      done();
    })
  })

  describe('Unicode to Zawgyi', () => {
    it('Convert to Unicode', done => {
      Rabbit.uni2zg("မင်္ဂလာပါ").should.equal("မဂၤလာပါ");
      Rabbit.uni2zg("သီဟိုဠ်မှ ဉာဏ်ကြီးရှင်သည် အာယုဝဍ်ဎနဆေးညွှန်းစာကို ဇလွန်ဈေးဘေးဗာဒံပင်ထက် အဓိဋ္ဌာန်လျက် ဂဃနဏဖတ်ခဲ့သည်။").should.equal("သီဟိုဠ္မွ ဉာဏ္ႀကီးရွင္သည္ အာယုဝဍ္ဎနေဆးၫႊန္းစာကို ဇလြန္ေဈးေဘးဗာဒံပင္ထက္ အဓိ႒ာန္လ်က္ ဂဃနဏဖတ္ခဲ့သည္။");
      Rabbit.uni2zg("ယေဓမ္မာ ဟေတုပ္ပဘဝါ တေသံ ဟေတုံ တထာဂတော အာဟ တေသဉ္စ ယောနိရောဓေါ ဧဝံ ဝါဒီ မဟာသမဏော။").should.equal("ေယဓမၼာ ေဟတုပၸဘဝါ ေတသံ ေဟတုံ တထာဂေတာ အာဟ ေတသၪၥ ေယာနိေရာေဓါ ဧဝံ ဝါဒီ မဟာသမေဏာ။");
      Rabbit.uni2zg("Rabbit ကွန်ဗက်တာကို သိလား").should.equal("Rabbit ကြန္ဗက္တာကို သိလား");
      done();
    })
  })
})
